! ###########################################################
!            Satellite Data Simulation Unit v2
!                     - VIRparameters -
!
! This module defines variables used for vis/IR simulator.
! Partly inherited from the RSTAR6b module.
!
module VIRparameters
  implicit none
  integer,parameter:: kna0 = 1     !! max number of solar incidences
  integer,parameter:: kna1u= 1     !! max number of emergent nadir angles
  integer,parameter:: knfi = 1     !! max number of azimuthal angles
  integer,parameter:: knw0 = 1     !! max number of sub-wavelength grids
  integer,parameter:: knw  = 1     !! max number of emergent nadir angles
  integer,parameter:: kntau= 50    !! max number of optical thickness
  integer,parameter:: knln = 49    !! max number of layers
  integer,parameter:: kndm = 10    !! max number of 
  integer,parameter:: knl  = 50    !! max number of 
  integer,parameter:: knm0 = 28    !! max number of gas species
  integer,parameter:: kpoly = 4    !! max number of input aerosol species
  integer,parameter:: kaw  = 17    !! max number of aerosol growth
  integer,parameter:: kwlv = 210   !! max number of refractive index
  integer,parameter:: knv  = 9     !! max number of basic aerosol species
  integer,parameter:: kptc = 20    !! max number of aerosol species
  integer,parameter:: klgn1= 400   !! max number of phase function
  integer,parameter:: kp   = 26    !! number of pressure grids
  integer,parameter:: kt   = 3     !! number of temperature grids
  integer,parameter:: kmol = 7     !! number of major gases
  integer,parameter:: kmol1= kmol+1!! number of major gases + self

  integer,parameter:: kda  = 2     !! 
  integer,parameter:: knang= 80    !! 
  integer,parameter:: kplk1= 4     !! 
  integer,parameter:: kww  = 200   !! 
  integer,parameter:: kch  = 2     !! 

! for rfidxb
!  integer,parameter:: kintvl = 75
!  integer,parameter:: kpol = 1
!
  integer,parameter:: knm  = knm0  !! 
  integer,parameter:: kgs  = 53    !! 
  integer,parameter:: kna1 = 4     !! 
  integer,parameter:: knln1 = knln + 1     !! 
  integer,parameter:: knw01 = knw0 + 1     !! 
  integer,parameter:: kndm2 = 2 * kndm     !! 
  integer,parameter:: knlnm = knln1
  integer,parameter:: knlnm1 = knlnm + 1
  integer,parameter:: krowij = kndm * (kndm + 1) / 2

  integer,parameter:: knltm=knln1
  integer,parameter:: knsb=knln1
  integer,parameter:: knlt=knln1
!
  real(8):: pi,rad
  real(8):: pstd=1013.25d0, tstd=273.15d0
!
! SDSU variables
!
  real(8), dimension(:),   allocatable :: prs_sdsu,tmp_sdsu,rhm_sdsu,hgt_sdsu
  real(8), dimension(:),   allocatable :: Wcw_sdsu,Wci_sdsu,Wrr_sdsu
  real(8), dimension(:),   allocatable :: Wsn_sdsu,Wgr_sdsu,Whl_sdsu
  real(8), dimension(:),   allocatable :: Ncw_sdsu,Nci_sdsu,Nrr_sdsu
  real(8), dimension(:),   allocatable :: Nsn_sdsu,Ngr_sdsu,Nhl_sdsu
  real(8), dimension(:,:), allocatable :: cng_sdsu
  real(8) :: tsk_sdsu
!
! cext, csca, and phsf stored in the LUT for rain (rr), cloud ice (ci),
! cloud water (cw), snow (sn), graupel (gr), hail (hl), and melting
! particles (ml).
!
   real, dimension(:,:,:),   allocatable :: cextrr_lut,cscarr_lut
   real, dimension(:,:,:),   allocatable :: cextci_lut,cscaci_lut
   real, dimension(:,:,:),   allocatable :: cextcw_lut,cscacw_lut
   real, dimension(:,:,:),   allocatable :: cextsn_lut,cscasn_lut
   real, dimension(:,:,:),   allocatable :: cextgr_lut,cscagr_lut
   real, dimension(:,:,:),   allocatable :: cexthl_lut,cscahl_lut
   real, dimension(:,:,:,:), allocatable :: phsfrr_lut,phsfci_lut,phsfcw_lut
   real, dimension(:,:,:,:), allocatable :: phsfsn_lut,phsfgr_lut,phsfhl_lut
!
! / Updated for SDSU v.2.1.0 /
! pts_hydro  : LUT hydrometeor water content vector (in [g/m3])
! ptn_????   : LUT hydrometeor number concentration vector (in [/m3])
!              ????=cldi, cldw, rain, snow, grpl, or hail
! pts_temp_w : LUT temperature vector (in [K]) for liquid hydrometeors
! pts_temp_i : LUT temperature vector (in [K]) for frozen hydrometeors
! npts_hydro : LUT hydrometeor water content dimension size
! npts_temp  : LUT temperature dimension size
! npts_ncnc  : LUT hydrometeor number concentration dimension size
! ( These parameters will be read in from the LUTs. )
!
   real, dimension(:), allocatable :: pts_hydro, pts_temp_w, pts_temp_i
   real, dimension(:), allocatable :: ptn_cldi, ptn_cldw, ptn_rain
   real, dimension(:), allocatable :: ptn_snow, ptn_grpl, ptn_hail
   integer :: npts_hydro, npts_temp, npts_ncnc
!
! Angle definition
!
  integer, parameter :: nang = 74
  real(8), dimension(knang) :: ang(1:nang) = (/ &
  0.000D+00,2.000D-01,4.000D-01,6.000D-01,8.000D-01,1.000D+00,1.500D+00, &
  2.000D+00,2.500D+00,3.000D+00,3.500D+00,4.000D+00,4.500D+00,5.000D+00, &
  6.000D+00,7.000D+00,8.000D+00,9.000D+00,1.000D+01,1.250D+01,1.500D+01, &
  1.750D+01,2.000D+01,2.500D+01,3.000D+01,3.500D+01,4.000D+01,4.500D+01, &
  5.000D+01,5.500D+01,6.000D+01,6.500D+01,7.000D+01,7.500D+01,8.000D+01, &
  8.500D+01,9.000D+01,9.250D+01,9.500D+01,9.750D+01,1.000D+02,1.025D+02, &
  1.050D+02,1.075D+02,1.100D+02,1.125D+02,1.150D+02,1.175D+02,1.200D+02, &
  1.225D+02,1.250D+02,1.275D+02,1.300D+02,1.325D+02,1.350D+02,1.375D+02, &
  1.400D+02,1.425D+02,1.450D+02,1.475D+02,1.500D+02,1.525D+02,1.550D+02, &
  1.575D+02,1.600D+02,1.625D+02,1.650D+02,1.675D+02,1.700D+02,1.720D+02, &
  1.740D+02,1.760D+02,1.780D+02,1.800D+02 /)
!
 end module VIRparameters
